@@ -3,7 +3,7 @@ from __future__ import absolute_import
 from sentry_sdk._types import MYPY
 from sentry_sdk.hub import Hub
 from sentry_sdk.integrations import Integration, DidNotEnable
-from sentry_sdk.tracing_utils import RecordSqlQueries
+from sentry_sdk.tracing_utils import record_sql_queries
 
 try:
     from sqlalchemy.engine import Engine  # type: ignore
@@ -50,7 +50,7 @@ def _before_cursor_execute(
     if hub.get_integration(SqlalchemyIntegration) is None:
         return
 
-    ctx_mgr = RecordSqlQueries(
+    ctx_mgr = record_sql_queries(
         hub,
         cursor,
         statement,
@@ -58,29 +58,32 @@ def _before_cursor_execute(
         paramstyle=context and context.dialect and context.dialect.paramstyle or None,
         executemany=executemany,
     )
-    conn._sentry_sql_span_manager = ctx_mgr
+    context._sentry_sql_span_manager = ctx_mgr
 
     span = ctx_mgr.__enter__()
 
     if span is not None:
-        conn._sentry_sql_span = span
+        context._sentry_sql_span = span
 
 
-def _after_cursor_execute(conn, cursor, statement, *args):
-    # type: (Any, Any, Any, *Any) -> None
+def _after_cursor_execute(conn, cursor, statement, parameters, context, *args):
+    # type: (Any, Any, Any, Any, Any, *Any) -> None
     ctx_mgr = getattr(
-        conn, "_sentry_sql_span_manager", None
+        context, "_sentry_sql_span_manager", None
     )  # type: ContextManager[Any]
 
     if ctx_mgr is not None:
-        conn._sentry_sql_span_manager = None
+        context._sentry_sql_span_manager = None
         ctx_mgr.__exit__(None, None, None)
 
 
 def _handle_error(context, *args):
     # type: (Any, *Any) -> None
-    conn = context.connection
-    span = getattr(conn, "_sentry_sql_span", None)  # type: Optional[Span]
+    execution_context = context.execution_context
+    if execution_context is None:
+        return
+
+    span = getattr(execution_context, "_sentry_sql_span", None)  # type: Optional[Span]
 
     if span is not None:
         span.set_status("internal_error")
@@ -89,9 +92,9 @@ def _handle_error(context, *args):
     # from SQLAlchemy codebase it does seem like any error coming into this
     # handler is going to be fatal.
     ctx_mgr = getattr(
-        conn, "_sentry_sql_span_manager", None
+        execution_context, "_sentry_sql_span_manager", None
     )  # type: ContextManager[Any]
 
     if ctx_mgr is not None:
-        conn._sentry_sql_span_manager = None
+        execution_context._sentry_sql_span_manager = None
         ctx_mgr.__exit__(None, None, None)
